{
    "$graph": [
        {
            "class": "CommandLineTool",
            "label": "Quality control filtering step using the BioPython package.",
            "hints": [
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "run_quality_filtering.py"
            ],
            "inputs": [
                {
                    "type": "string",
                    "id": "#qc-filtering.cwl/input_file_format"
                },
                {
                    "type": "int",
                    "default": 100,
                    "label": "Minimum read or contig length",
                    "doc": "Specify the minimum read or contig length for sequences to pass QC filtering.\n",
                    "id": "#qc-filtering.cwl/min_length"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "Trimmed sequence file",
                    "doc": "Trimmed and FASTQ to FASTA converted sequences file.\n",
                    "id": "#qc-filtering.cwl/seq_file"
                },
                {
                    "type": "string",
                    "default": "stats_summary",
                    "label": "Post QC stats output file name",
                    "doc": "Give a name for the file which will hold the stats after QC.\n",
                    "id": "#qc-filtering.cwl/stats_file_name"
                },
                {
                    "type": "int",
                    "label": "Number of submitted sequences",
                    "doc": "Number of originally submitted sequences as in the user submitted FASTQ file - single end FASTQ or pair end merged FASTQ file.\n",
                    "id": "#qc-filtering.cwl/submitted_seq_count"
                }
            ],
            "arguments": [
                {
                    "position": 2,
                    "valueFrom": "$(inputs.seq_file.nameroot).fasta"
                },
                {
                    "position": 3,
                    "valueFrom": "$(inputs.stats_file_name)"
                },
                {
                    "position": 4,
                    "valueFrom": "$(inputs.submitted_seq_count)"
                },
                {
                    "position": 5,
                    "prefix": "--min_length",
                    "valueFrom": "$(inputs.min_length)"
                },
                {
                    "position": 6,
                    "prefix": "--extension",
                    "valueFrom": "$(inputs.input_file_format)"
                }
            ],
            "id": "#qc-filtering.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute",
            "outputs": [
                {
                    "label": "Filtered output file",
                    "format": "http://edamontology.org/format_1929",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.seq_file.nameroot).fasta"
                    },
                    "id": "#qc-filtering.cwl/filtered_file"
                },
                {
                    "label": "Stats summary output file",
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.stats_file_name)"
                    },
                    "id": "#qc-filtering.cwl/stats_summary_file"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "label": "Post QC-ed input analysis of sequence file",
            "hints": [
                {
                    "dockerPull": "qc-stats:latest",
                    "class": "DockerRequirement"
                }
            ],
            "requirements": [
                {
                    "listing": [
                        {
                            "entry": "$({class: 'Directory', listing: []})",
                            "entryname": "$(inputs.out_dir_name)",
                            "writable": true
                        }
                    ],
                    "class": "InitialWorkDirRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 4,
                    "ramMin": 900,
                    "class": "ResourceRequirement"
                }
            ],
            "baseCommand": [
                "MGRAST_base.py"
            ],
            "inputs": [
                {
                    "type": "File",
                    "format": "http://edamontology.org/format_1929",
                    "inputBinding": {
                        "prefix": "-i"
                    },
                    "id": "#qc-stats.cwl/QCed_reads"
                },
                {
                    "label": "Prefix for the files associated with GC distribution",
                    "type": "string",
                    "default": "GC-distribution.out",
                    "id": "#qc-stats.cwl/gc_sum"
                },
                {
                    "label": "Prefix for the files assocaited with sequence length distribution",
                    "type": "string",
                    "default": "seq-length.out",
                    "id": "#qc-stats.cwl/length_sum"
                },
                {
                    "label": "Maximum number of sequences to sub-sample",
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 2000000,
                    "id": "#qc-stats.cwl/max_seq"
                },
                {
                    "label": "Prefix for the files associated with nucleotide distribution",
                    "type": "string",
                    "default": "nucleotide-distribution.out",
                    "id": "#qc-stats.cwl/nucleotide_distribution"
                },
                {
                    "label": "Specifies output subdirectory",
                    "type": "string",
                    "default": "qc-statistics",
                    "id": "#qc-stats.cwl/out_dir_name"
                },
                {
                    "label": "Specifies the number of sequences in the input read file (FASTA formatted)",
                    "type": "int",
                    "id": "#qc-stats.cwl/sequence_count"
                },
                {
                    "label": "File names for summary of sequences, e.g. number, min/max length etc.",
                    "type": "string",
                    "default": "summary.out",
                    "id": "#qc-stats.cwl/summary"
                }
            ],
            "outputs": [
                {
                    "label": "Contains all stats output files",
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)"
                    },
                    "id": "#qc-stats.cwl/output_dir"
                },
                {
                    "label": "Contains the summary statistics for the input sequence file",
                    "type": "File",
                    "format": "https://www.iana.org/assignments/media-types/text/plain",
                    "outputBinding": {
                        "glob": "$(inputs.out_dir_name)/$(inputs.summary)"
                    },
                    "id": "#qc-stats.cwl/summary_out"
                }
            ],
            "arguments": [
                {
                    "position": 1,
                    "prefix": "-o",
                    "valueFrom": "$(inputs.out_dir_name)/$(inputs.summary)"
                },
                {
                    "position": 2,
                    "prefix": "-d",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.nucleotide_distribution, suffix);\n}\n"
                },
                {
                    "position": 3,
                    "prefix": "-g",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.gc_sum, suffix);\n}\n"
                },
                {
                    "position": 4,
                    "prefix": "-l",
                    "valueFrom": "${ var suffix = '.full';\n   if (inputs.sequence_count > inputs.max_seq) {\n     suffix = '.sub-set';\n   }\n   return \"\".concat(inputs.out_dir_name, '/', inputs.length_sum, suffix);\n}\n"
                },
                {
                    "position": 5,
                    "valueFrom": "${ if (inputs.sequence_count > inputs.max_seq) { return '-m '.concat(inputs.max_seq)} else { return ''} }"
                }
            ],
            "id": "#qc-stats.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "Replaces problematic characters from FASTA headers with dashes",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 1024,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences"
                }
            ],
            "stdin": "$(inputs.sequences.path)",
            "baseCommand": [
                "tr",
                "\" /|<_;#\"",
                "-------"
            ],
            "stdout": "$(inputs.sequences.nameroot).unfiltered_fasta",
            "outputs": [
                {
                    "type": "File",
                    "id": "#clean_fasta_headers.cwl/sequences_with_cleaned_headers",
                    "outputBinding": {
                        "glob": "$(inputs.sequences.nameroot).unfiltered_fasta"
                    }
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#clean_fasta_headers.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "ShellCommandRequirement"
                }
            ],
            "baseCommand": [
                "grep",
                "-c",
                "^>"
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#count_fasta.cwl/number"
                },
                {
                    "type": "File",
                    "streamable": true,
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#count_fasta.cwl/sequences"
                }
            ],
            "arguments": [
                {
                    "valueFrom": "|",
                    "position": 2,
                    "shellQuote": false
                },
                {
                    "valueFrom": "cat",
                    "shellQuote": false,
                    "position": 3
                }
            ],
            "stdout": "grepcount",
            "outputs": [
                {
                    "type": "int",
                    "outputBinding": {
                        "glob": "grepcount",
                        "loadContents": true,
                        "outputEval": "${\n  var grep_count = parseInt(self[0].contents) || 0;\n  if (grep_count === 0) {\n    return 0;\n  } else {\n    return parseInt(grep_count / inputs.number);\n  }\n}\n"
                    },
                    "id": "#count_fasta.cwl/count"
                }
            ],
            "id": "#count_fasta.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 5000,
                    "class": "ResourceRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "inputBinding": {
                        "position": 1,
                        "prefix": "-i"
                    },
                    "id": "#generate_checksum.cwl/input_file"
                }
            ],
            "baseCommand": [
                "generate_checksum.py"
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*sha1"
                    },
                    "id": "#generate_checksum.cwl/hashsum"
                }
            ],
            "hints": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "alpine:3.7"
                }
            ],
            "id": "#generate_checksum.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "unzip files",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMin": 1,
                    "ramMin": 2000,
                    "class": "ResourceRequirement"
                }
            ],
            "hints": [
                {
                    "dockerPull": "alpine:3.7",
                    "class": "DockerRequirement"
                },
                {
                    "packages": [
                        {
                            "specs": null,
                            "package": "gunzip"
                        }
                    ],
                    "class": "SoftwareRequirement"
                }
            ],
            "inputs": [
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "is this an assembly file?",
                    "id": "#multiple-gunzip.cwl/assembly"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 2
                    },
                    "label": "for seqprep result: unmerged forward seqprep output or single end reads",
                    "id": "#multiple-gunzip.cwl/forward_unmerged_reads"
                },
                {
                    "type": [
                        "null",
                        "boolean"
                    ],
                    "label": "are these raw reads or amplicon reads?",
                    "id": "#multiple-gunzip.cwl/reads"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "format": "http://edamontology.org/format_1930",
                    "inputBinding": {
                        "position": 3
                    },
                    "label": " unmerged reverse seqprep output",
                    "id": "#multiple-gunzip.cwl/reverse_unmerged_reads"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 1
                    },
                    "label": "merged seq prep output",
                    "id": "#multiple-gunzip.cwl/target_reads"
                }
            ],
            "baseCommand": [
                "gunzip",
                "-c"
            ],
            "outputs": [
                {
                    "type": "File",
                    "format": "$(inputs.target_reads.format)",
                    "id": "#multiple-gunzip.cwl/unzipped_file",
                    "outputBinding": {
                        "glob": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }"
                    }
                }
            ],
            "stdout": "${ var ext = \"\"; if (inputs.assembly) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTA.unfiltered'; } if (inputs.reads) { ext = inputs.target_reads.nameroot.split('.')[0] + '_FASTQ.fastq'; } return ext; }",
            "id": "#multiple-gunzip.cwl",
            "https://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "https://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "CommandLineTool",
            "label": "output QC-FAILED or QC-PASSED file as intermediate flag",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "coresMax": 1,
                    "ramMin": 200,
                    "class": "ResourceRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#qc-flag.cwl/qc_count"
                }
            ],
            "baseCommand": [
                "touch"
            ],
            "arguments": [
                {
                    "valueFrom": "${ var flag = \"\"; if (inputs.qc_count == 0) { flag = 'QC-FAILED'; } else { flag = 'QC-PASSED'; } return flag; }"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "QC-*"
                    },
                    "id": "#qc-flag.cwl/qc-flag"
                }
            ],
            "id": "#qc-flag.cwl",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "ResourceRequirement",
                    "ramMin": 20000
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "int",
                    "id": "#main/contig_min_length"
                },
                {
                    "type": "File",
                    "id": "#main/contigs"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/length_filter/filtered_file",
                    "id": "#main/filtered_fasta"
                },
                {
                    "type": "File",
                    "outputSource": "#main/hashsum/hashsum",
                    "id": "#main/hashsum_input"
                },
                {
                    "type": "Directory",
                    "outputSource": "#main/qc_stats/output_dir",
                    "id": "#main/qc-statistics_folder"
                },
                {
                    "type": "File",
                    "outputSource": "#main/QC-FLAG/qc-flag",
                    "id": "#main/qc-status"
                },
                {
                    "type": "File",
                    "outputSource": "#main/length_filter/stats_summary_file",
                    "id": "#main/qc_summary"
                }
            ],
            "steps": [
                {
                    "run": "#qc-flag.cwl",
                    "in": [
                        {
                            "source": "#main/count_processed_reads/count",
                            "id": "#main/QC-FLAG/qc_count"
                        }
                    ],
                    "out": [
                        "#main/QC-FLAG/qc-flag"
                    ],
                    "id": "#main/QC-FLAG"
                },
                {
                    "in": [
                        {
                            "source": "#main/unzip/unzipped_file",
                            "id": "#main/clean_headers/sequences"
                        }
                    ],
                    "out": [
                        "#main/clean_headers/sequences_with_cleaned_headers"
                    ],
                    "run": "#clean_fasta_headers.cwl",
                    "label": "removes spaces in some headers",
                    "id": "#main/clean_headers"
                },
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#main/count_processed_reads/number"
                        },
                        {
                            "source": "#main/length_filter/filtered_file",
                            "id": "#main/count_processed_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/count_processed_reads/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#main/count_processed_reads"
                },
                {
                    "in": [
                        {
                            "default": 1,
                            "id": "#main/count_reads/number"
                        },
                        {
                            "source": "#main/unzip/unzipped_file",
                            "id": "#main/count_reads/sequences"
                        }
                    ],
                    "out": [
                        "#main/count_reads/count"
                    ],
                    "run": "#count_fasta.cwl",
                    "id": "#main/count_reads"
                },
                {
                    "run": "#generate_checksum.cwl",
                    "in": [
                        {
                            "source": "#main/contigs",
                            "id": "#main/hashsum/input_file"
                        }
                    ],
                    "out": [
                        "#main/hashsum/hashsum"
                    ],
                    "id": "#main/hashsum"
                },
                {
                    "in": [
                        {
                            "default": "fasta",
                            "id": "#main/length_filter/input_file_format"
                        },
                        {
                            "source": "#main/contig_min_length",
                            "id": "#main/length_filter/min_length"
                        },
                        {
                            "source": "#main/clean_headers/sequences_with_cleaned_headers",
                            "id": "#main/length_filter/seq_file"
                        },
                        {
                            "default": "qc_summary",
                            "id": "#main/length_filter/stats_file_name"
                        },
                        {
                            "source": "#main/count_reads/count",
                            "id": "#main/length_filter/submitted_seq_count"
                        }
                    ],
                    "out": [
                        "#main/length_filter/filtered_file",
                        "#main/length_filter/stats_summary_file"
                    ],
                    "run": "#qc-filtering.cwl",
                    "id": "#main/length_filter"
                },
                {
                    "in": [
                        {
                            "source": "#main/length_filter/filtered_file",
                            "id": "#main/qc_stats/QCed_reads"
                        },
                        {
                            "source": "#main/count_processed_reads/count",
                            "id": "#main/qc_stats/sequence_count"
                        }
                    ],
                    "out": [
                        "#main/qc_stats/output_dir",
                        "#main/qc_stats/summary_out"
                    ],
                    "run": "#qc-stats.cwl",
                    "id": "#main/qc_stats"
                },
                {
                    "in": [
                        {
                            "default": true,
                            "id": "#main/unzip/assembly"
                        },
                        {
                            "source": "#main/contigs",
                            "id": "#main/unzip/target_reads"
                        }
                    ],
                    "out": [
                        "#main/unzip/unzipped_file"
                    ],
                    "run": "#multiple-gunzip.cwl",
                    "id": "#main/unzip"
                }
            ],
            "id": "#main",
            "http://schema.org/license": "https://www.apache.org/licenses/LICENSE-2.0",
            "http://schema.org/copyrightHolder": "EMBL - European Bioinformatics Institute"
        }
    ],
    "cwlVersion": "v1.0",
    "$schemas": [
        "http://edamontology.org/EDAM_1.16.owl",
        "https://schema.org/version/latest/schemaorg-current-http.rdf"
    ],
    "$namespaces": {
        "edam": "http://edamontology.org/",
        "s": "http://schema.org/"
    }
}
